from setuptools import setup, find_packages

with open("README.md", 'r') as f:
	long_description = f.read()

def parse_requirements(filename):
    with open(filename, 'r') as f:
        return f.read().splitlines()

setup(
	name='PassioGo Vehicle Fix',
	version="0.0.1",
	description="An unofficial API for Passio Go",
	long_description=long_description,
	long_description_content_type='text/markdown',
	author='Antonios Theocharopoulos',
	author_email='antoniostheo06@gmail.com',
	url="https://github.com/AntoniosTheo06/PassioGoVehicleFix",
	packages=find_packages(),
    include_package_data=True,
    install_requires=parse_requirements('requirements.txt'),
    package_data={
        '': ['requirements.txt'],
    },
	py_modules=find_packages(),
	project_urls = {
		'Documentation': 'https://passiogo.readthedocs.io/',
		'GitHub': 'https://github.com/AntoniosTheo06/PassioGoVehicleFix',
	},
)